## Command memory ##

As long as the 'memory' section is enabled in your context layout (which it is
by default), you can register addresses, lengths, and grouping size.

![memory watch](http://i.imgur.com/NXYwSwW.png)

### Adding a watch
`memory watch <ADDRESS> [SIZE] [(qword|dword|word|byte)]`

### Removing a watch
`memory unwatch <ADDRESS>`

### Listing watches
`memory list`

### Clearing watches
`memory clear`

